@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+# template 18
 """
 Python supplemental features
 ----------------------------
@@ -20,7 +21,7 @@ import gzip
 import shutil
 
 
-__version__ = '1.0.5'
+__version__ = '1.0.6'
 
 
 def fake_setup(**kwargs):
@@ -30,18 +31,13 @@ def fake_setup(**kwargs):
 def read_setup():
     setup_info = os.path.abspath(
         os.path.join(os.path.dirname(__file__), 'setup.info'))
-    # setup_file = os.path.abspath(
-    #     os.path.join(os.path.dirname(__file__), '..', '..', 'setup.py'))
-    # if os.path.isfile(setup_file):
-    #     shutil.copy(setup_file, setup_info)
     if not os.path.isfile(setup_info):
         setup_info = os.path.abspath(
             os.path.join(os.path.dirname(__file__), '..', 'setup.py'))
     setup_args = {}
     if os.path.isfile(setup_info):
         with open(setup_info, 'r') as fd:
-            content = fd.read().replace('setup(', 'fake_setup(')
-            exec(content)
+            exec(fd.read().replace('setup(', 'fake_setup('))
             setup_args = globals()['setup_args']
     else:
         print('Not internal configuration file found!')
@@ -90,7 +86,7 @@ def copy_pkg_data(setup_args, verbose):
             for pkg in setup_args['package_data'].keys():
                 for fn in setup_args['package_data'][pkg]:
                     base = os.path.basename(fn)
-                    if base == 'setup.info':
+                    if base in ('setup.info', '*'):
                         continue
                     full_fn = os.path.abspath(os.path.join(pkgpath, fn))
                     if base.endswith('.man') and man_path:
@@ -98,7 +94,10 @@ def copy_pkg_data(setup_args, verbose):
                             help_text = fd.read()
                         tgt_fn = os.path.join(man_path, '%s.8.gz' % base[:-4])
                         with gzip.open(tgt_fn, 'w') as fd:
-                            fd.write(help_text)
+                            if sys.version_info[0] == 3:
+                                fd.write(help_text.encode('utf-8'))
+                            else:
+                                fd.write(help_text)
                         continue
                     if lib_path:
                         tgt_fn = os.path.join(lib_path, base)
@@ -121,7 +120,7 @@ def copy_pkg_data(setup_args, verbose):
                         #     if verbose:
                         #         print('$ ln -s %s %s' % (full_fn, tgt_fn))
                         #     os.symlink(full_fn, tgt_fn)
-            # TODO> compatibility mode to remeve early
+            # TODO> compatibility mode to remove early
             if lib_path and bin2_path:
                 for base in ('z0librc', 'odoorc', 'travisrc'):
                     full_fn = os.path.join(bin2_path, base)
@@ -157,4 +156,4 @@ def main(cli_args=None):
             print(text)
     elif action in ('-C', '--copy-pkg-data'):
         copy_pkg_data(setup_args, verbose)
-    return 0
+    return 0
\ No newline at end of file
